import { h } from "vue"
import { ElMessageBox } from "element-plus"
import { mapPropertyToLabel, requiredProps } from "./columns-config"
import { mapLabelToSource, mapLabelToType, sourceOptions, typeOptions } from "../../config/shared"
import { mapLabelToInvtype, xs_inv_type_list } from "/@/utils/status"

function onDisplayErrorMessage(errors) {
    ElMessageBox({
        type: 'warning',
        title: '数据校验失败',
        message: h('div', { style: 'display: flex, flex-direction: column' }, {
            default: () => Object.keys(errors).reduce((prev, index) => {
                return [
                    ...prev,
                    h('p', {}, '第' + index  + '行,' + errors[index])
                ]
            }, [])
        })
    })
}


export function isValidRequired(results: any[]) {
    const errors = {}

    let isTypeError = false

    for (const sourceIndex in results) {
        const item = results[sourceIndex];
        const index = Number(sourceIndex) + 1;

        for (const key in item) {
            const value = String(item[key]).trim()

            if (requiredProps.includes(key) && (!value || !String(value).trim())) {
                if (errors[index]) {
                    errors[index] = errors[index] += '、' + mapPropertyToLabel[key]
                } else {
                    errors[index] = mapPropertyToLabel[key]
                }
            } else if (key === 'check_type' && !mapLabelToType[value]){
                isTypeError = true
            }
        }

        if (errors[index]) {
            errors[index] += '不能为空'
            if (isTypeError) errors[index] += ' , 盘点类型必须为' + typeOptions.map(({ label }) => label).join('、')
        } else {
            if (isTypeError) errors[index] = '盘点类型必须为' + typeOptions.map(({ label }) => label).join('、')
        }
    }


    if (Object.keys(errors).length === 0) {
        return true
    } else {
        onDisplayErrorMessage(errors)
        return false
    }
}

export function isImportDataValid(results: any[]) {
    /* 校验必填字段是否填入 */
    if (!isValidRequired(results)) { return false }
    return true
}