const columns = [
  {
    type: "index",
    fixed: "left",
    label: "序号",
    width: "50"
  },
  {
    label: '购买方公司纳税号',
    prop: 'buyer_code',
    minWidth: '130px',
    required: true,
    defaultData: [
      '91110118MACEA1R94G',
      '91110118MACEA1R94G'
    ]
  },
  {
    label: '购买方公司名称',
    prop: 'buyer_name',
    minWidth: '130px',
    required: true,
    defaultData: [
      '北京锦兴弘昌科技有限公司',
      '北京锦兴弘昌科技有限公司'
    ]
  },
  {
    label: '销售方公司纳税号',
    prop: 'seller_code',
    minWidth: '130px',
    required: true,
    defaultData: [
      '91110113MA008J790J',
      '91110113MA008J790J'
    ]
  },
  {
    label: '销售方公司名称',
    prop: 'seller_name',
    minWidth: '130px',
    required: true,
    defaultData: [
      '北京百辰荣达国际科贸有限公司',
      '北京百辰荣达国际科贸有限公司'
    ]
  },

  {
    label: '商品来源',
    prop: 'good_source',
    minWidth: '100px',
    required: true,
    defaultData: [
      '采销结算',
      '非采销结算'
    ]
  },
  {
    label: '订单商品类型',
    prop: 'good_type',
    minWidth: '120px',
    required: true,
    defaultData: [
      '咨询商品',
      '库存商品'
    ]
  },
  {
    label: '成本状态',
    prop: 'basic_status',
    minWidth: '120px',
    required: true,
    defaultData: [
      '真实成本',
      '预估成本'
    ]
  },
  {
    label: '发票商品名称',
    prop: 'inv_good_name',
    minWidth: '100px',
    required: true,
    defaultData: [
      '泰康专版金钥匙5g',
      '拉杆箱'
    ]
  },
  {
    label: '订单商品名称',
    prop: 'goodName',
    minWidth: '100px',
    required: true,
    defaultData: [
      '泰康专版金钥匙5g',
      '拉杆箱'
    ]
  },
  {
    label: '商品编号',
    prop: 'skuCode',
    minWidth: '100px',
    required: '商品来源为采销结算时必填',
    defaultData: [
      'SKU2408091355123018',
      ''
    ]
  },
  {
    label: '订单单位',
    prop: 'unit',
    minWidth: '80px',
    required: true,
    defaultData: [
      '个',
      '个',
    ]
  },
  {
    label: '规格',
    prop: 'spec',
    minWidth: '80px',
    defaultData: [
      '',
      '',
    ]
  },
  {
    label: '重量(g)',
    prop: 'unit_weight',
    minWidth: '80px',
    defaultData: [
      '',
      '',
    ]
  },
  {
    label: '发票类型',
    prop: 'inv_type',
    minWidth: '80px',
    required: true,
    defaultData: [
      '专票',
      '普票',
    ]
  },
  {
    label: '成本税前单价',
    prop: 'subunit_price',
    minWidth: '110px',
    required: true,
    defaultData: [
      '725.2',
      '194.04'
    ],
  },
  {
    label: '成本税后单价',
    prop: 'unit_price',
    minWidth: '110px',
    required: true,
    defaultData: [
      '725.2',
      '194.04'
    ],
  },
  {
    label: '商品代码',
    prop: 'good_code',
    minWidth: '110px',
    defaultData: [
      '',
      ''
    ],
  },
  {
    label: '进项税目编号',
    prop: 'cat_code',
    required: true,
    minWidth: '110px',
    defaultData: [
      '6160000000000000000',
      '6160000000000000000'
    ],
  },
  {
    label: '进项税率',
    prop: 'cat_tax',
    required: true,
    minWidth: '110px',
    defaultData: [
      '1%',
      '3%'
    ],
  },
  {
    label: '分光',
    prop: 'spectral',
    minWidth: '110px',
    defaultData: [
      '',
      ''
    ],
  }
]

const productTemplate = new Array(3).fill(1).map((_, index) => (columns.slice(1).reduce((prev, current) => {
  const isRequired = index === 0
  let defaultValue = ''

  if (isRequired) {
    if(typeof current.required === 'string'){
      defaultValue = current.required
    }else {
      defaultValue = current.required ? '必填' : ''
    }
  } else {
    defaultValue = current.defaultData[index - 1]
  }

  return { ...prev, [current.label]: defaultValue }
}, {})))

export const mapLabelToProp = columns.reduce((prev, current) => ({
  ...prev,
  [current.label]: current.prop
}), {})


export const mapPropertyToLabel = columns.reduce((prev, current) => ({
  ...prev,
  [current.prop]: current.label
}), {})

export const requiredProps = columns.filter(column => !!column.required && typeof column.required === 'boolean').map(item => item.prop)

export { columns, productTemplate };
